#!/bin/bash

# Copyright (C) since 2006 NTT DATA Corporation
# 
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
SCRIPT_DIR=$(cd $(dirname $0);pwd)
. ${SCRIPT_DIR}/../hinemos_web.cfg


export PROG=`basename $0`
DIR=`dirname $0`
USER=`/usr/bin/whoami`
HOST=`hostname`

cd ${HINEMOS_WEB_HOME}/var/log

########################################
#  Environment Variable
########################################

unset _JAVA_OPTIONS

########################################
#  Local Message
########################################

# INFO
MSG_I001="waiting for WebClient shutdown..."
MSG_I002="WebClient stopped"

# WARN
MSG_W001="\
***************************************************************************\
\n\
*** Don't use this script! You should use \"service(systemctl)\" command. ***\
\n\
***************************************************************************"

# ERROR
MSG_E001="failed to stop WebClient"

########################################
# Function
########################################

# Logging
function Logging() {
	MODE=$2
	OPTS="-e"
	case ${MODE} in
		withline)
			EchoLine
			Logging "$1"
			EchoLine
			return 0
			;;
		noreturn)
			OPTS="${OPTS} -n"
			;;
		*)
			;;
	esac
	echo ${OPTS} "$1" >&2
	/usr/bin/logger "${PROG} $1"
}

function usage {
	echo "usage : ${PROG} [-F]"
	echo "options:"
	echo "  -q   quiet start"
	echo "  -F   force immediate shutdown without process check (dependency, current status)"
}

function shutdown {
	Logging "${MSG_I001}"
	${TOMCAT_HOME}/bin/catalina.sh stop 30 -force
	RET=$?
	
	return ${RET}
}

########################################
# SHELL
########################################

# check argument
for OPT in $@
do
	case ${OPT} in
		--help)
			usage
			exit 0
			;;
	esac
done

# option check
QUIET=0
while getopts qF OPT
do
	case ${OPT} in
		q)
			QUIET=1
			;;
		F)
			FORCE="true"
			;;
		*)
			ExitIllegalOptionErrorWithoutLogger
			;;
	esac
done

shift $(( $OPTIND - 1 ))

if [ ! $# = 0 ]
then
	ExitIllegalArgumentError
fi

if [ ${QUIET} -ne 1 ]
then
	Logging "${MSG_W001}"
fi

mv ${HINEMOS_WEB_LOG_DIR}/catalina.out ${HINEMOS_WEB_LOG_DIR}/catalina.out.`date +%Y-%m-%d_%H%M`

# shutdown process
if [ "x${FORCE}" != "xtrue" ]
then
	if [ -f ${CATALINA_PID} ]
	then
		read PID < ${CATALINA_PID}
		if [ `ps --no-headers --pid ${PID} e | grep -- "-DHinemos_Web" | wc -l` -gt 0 ]
		then
			shutdown
		fi
	else
		Logging "Hinemos WebClient is not running."
		exit 1
	fi
else
	shutdown
fi

## check process
if [ `ps --no-headers --pid ${PID} e | grep -- "-DHinemos_Web" | wc -l` -eq 0 ]
then
	Logging "Hinemos WebClient stopped."
	rm -f ${HINEMOS_LOCK_FILE}
	exit 0
fi

exit 1
