#!/bin/bash

SCRIPT_DIR=$(cd $(dirname $0);pwd)
. ${SCRIPT_DIR}/../../conf/hinemos_web.cfg

########################################
#  Local Variable
########################################

########################################
#  Local Message
########################################

# INFO
MSG_I001="clearing temporary tomcat data"
MSG_I101="successful in clearing temporary tomcat data."

# WARN
#MSG_W001="xxx"

# ERROR
MSG_E001="failed to delete tomcat work files."
MSG_E002="failed to clear temporary data."
MSG_E003="Hinemos WebClient is running..."
MSG_E004="Please stop WebClient and then retry."

########################################
# Function
########################################

function usage {
	echo "Usage: "
	echo "	$0 : Clear temporary data"
	echo
}

#
# truncate async worker persistence tables in PostgreSQL
#
function clean_cache_file {
	echo "${MSG_I001}"

	# remove plugins
	MSG=`rm -rf ${TOMCAT_HOME}/work/Catalina/localhost/ROOT/eclipse/plugins > /dev/null 2>&1`
	RET=$?
	if [ ${RET} -ne 0 ]
	then
		echo "$MSG"
		echo "${MSG_E001}"
		RET=$((16 + ${RET}))
		return ${RET}
	fi
	
	# remove features
	MSG=`rm -rf ${TOMCAT_HOME}/work/Catalina/localhost/ROOT/eclipse/features > /dev/null 2>&1`
	RET=$?
	if [ ${RET} -ne 0 ]
	then
		echo "$MSG"
		echo "${MSG_E001}"
		RET=$((32 + ${RET}))
		return ${RET}
	fi
	
	# remove configurations
	MSG=`rm -rf ${TOMCAT_HOME}/work/Catalina/localhost/ROOT/eclipse/configuration > /dev/null 2>&1`
	RET=$?
	if [ ${RET} -ne 0 ]
	then
		echo "$MSG"
		echo "${MSG_E001}"
		RET=$((32 + ${RET}))
		return ${RET}
	fi
	
	return 0
}

########################################
# SHELL
########################################

# check parameters
for OPT in $@
do
	case $OPT in
		--help|-h)
			usage
			exit 0
			;;
	esac
done

if [ ! $# = 0 ]
then
	usage
	exit 1
fi

# check process
if [ -f ${CATALINA_PID} ]
then
	read PID < ${CATALINA_PID}
	if [ `ps --no-headers --pid ${PID} e | grep -- "-DHinemos_Web" | wc -l` -gt 0 ]
	then
		echo "$MSG_E003"
		echo "$MSG_E004"
		exit 1
	fi
fi

# main
clean_cache_file
RET=$?
if [ ${RET} -ne 0 ]
then
	echo "${MSG_E002}"
	exit ${RET}
fi

########################################
# Termination Processing
########################################

echo "${MSG_I101}"
exit 0
